@@ -91,6 +91,7 @@ void IniConfig::clear ()
     emulation_s.sidModel      = SidConfig::MOS6581;
     emulation_s.forceModel    = false;
     emulation_s.filter        = true;
+    emulation_s.engine        = NULL;
 
     emulation_s.bias            = 0.0;
     emulation_s.filterCurve6581 = 0.0;
@@ -306,6 +307,8 @@ bool IniConfig::readEmulation (ini_fd_t ini)
     bool ret = true;
     (void) ini_locateHeading (ini, "Emulation");
 
+    ret &= readString (ini, "Engine", emulation_s.engine);
+
     {
         char *str;
         const bool res = readString (ini, "C64Model", str);
