@@ -95,7 +95,6 @@ int ConsolePlayer::args (int argc, const char *argv[])
     // default arg options
     m_driver.output = OUT_SOUNDCARD;
     m_driver.file   = false;
-    m_driver.sid    = EMU_RESIDFP;
 
     v1mute = v2mute = v3mute = false;
     v4mute = v5mute = v6mute = false;
@@ -353,6 +352,10 @@ int ConsolePlayer::args (int argc, const char *argv[])
             {
                 m_driver.sid = EMU_NONE;
             }
+            else if (strcmp (&argv[i][1], "-noaudio") == 0)
+            {
+                m_driver.output = OUT_NULL;
+            }
             else if (strcmp (&argv[i][1], "-cpu-debug") == 0)
             {
                 m_cpudebug = true;
@@ -541,6 +544,7 @@ void ConsolePlayer::displayDebugArgs ()
         << " --cpu-debug   display cpu register and assembly dumps" << endl
         << " --delay=<num> simulate c64 power on delay" << endl
 
-        << " --none        no audio output device" << endl
-        << " --nosid       no sid emulation" << endl;
+        << " --noaudio     no audio output device" << endl
+        << " --nosid       no sid emulation" << endl
+        << " --none        no audio output device and no sid emulation" << endl;
 }
